@@ -50,6 +50,7 @@ worker_router = AirflowRouter(
         [
             status.HTTP_400_BAD_REQUEST,
             status.HTTP_403_FORBIDDEN,
+            status.HTTP_409_CONFLICT,
         ]
     ),
 )
@@ -175,6 +176,19 @@ def register(
     worker: EdgeWorkerModel | None = session.scalar(query)
     if not worker:
         worker = EdgeWorkerModel(worker_name=worker_name, state=body.state, queues=body.queues)
+    else:
+        # Prevent duplicate workers unless the existing worker is in offline or unknown state
+        allowed_states_for_reuse = {
+            EdgeWorkerState.OFFLINE,
+            EdgeWorkerState.UNKNOWN,
+            EdgeWorkerState.OFFLINE_MAINTENANCE,
+        }
+        if worker.state not in allowed_states_for_reuse:
+            raise HTTPException(
+                status.HTTP_409_CONFLICT,
+                f"Worker '{worker_name}' is already active in state '{worker.state}'. "
+                f"Cannot start a duplicate worker with the same name.",
+            )
     worker.state = redefine_state(worker.state, body.state)
     worker.maintenance_comment = redefine_maintenance_comments(
         worker.maintenance_comment, body.maintenance_comments
